import requests
import json
import os  # Import the os module to work with file paths

# Define the Inspire HEP search query URL
query_url = "https://inspirehep.net/api/literature"

# Define the search query for papers citing the specific entry
cited_entry_id = "1221019"  # The ID of the entry to search citations for
query_params = {
    "q": f"refersto:recid:{cited_entry_id}",  # Query for citations to the specified entry
    "size": 1000,  # Adjust to fetch up to 1000 papers
    "sort": "mostrecent"  # Sort by most recent entries
}

# Make a request to the API
response = requests.get(query_url, params=query_params)

# Check if the request was successful
if response.status_code == 200:
    data = response.json()

    # Initialize HTML content with linked CSS file
    html_content = """
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Papers Acknowledging xPand</title>
        <link rel="stylesheet" href="style.css"> <!-- Link to the CSS file -->
        <style>
            li {
                margin-bottom: 20px; /* Add space between entries */
            }
        </style>
    </head>
    <body>
        <h1>Papers Acknowledging xPand</h1>
        <ul>
    """

    # Iterate over the retrieved papers and create numbered entries
    total_papers = len(data['hits']['hits'])
    for index, paper in enumerate(data['hits']['hits'], start=1):
        # Reverse the index for numbering from bottom to top
        number = total_papers - index + 1
        
        title = paper['metadata'].get('titles', [{}])[0].get('title', 'No Title')
        authors = ", ".join([author['full_name'] for author in paper['metadata'].get('authors', [])])

        # Handle journal, year, volume, and article ID information
        publication_info = paper['metadata'].get('publication_info', [])
        journal_info = None
        year = None
        volume = None
        artid = None

        if publication_info:
            for pub_info in publication_info:
                if 'journal_title' in pub_info:
                    journal_info = pub_info['journal_title']
                if 'year' in pub_info:
                    year = pub_info['year']
                if 'journal_volume' in pub_info:
                    volume = pub_info.get('journal_volume')  # Use .get() for safety
                if 'artid' in pub_info:
                    artid = pub_info.get('artid')  # Use .get() for safety

        # Retrieve arXiv number if available
        arxiv_number = None
        arxiv_info = paper['metadata'].get('arxiv_eprints', [])
        if arxiv_info:
            arxiv_number = arxiv_info[0].get('value')

        # Handle the DOI and external paper URL
        paper_url = None
        doi = paper['metadata'].get('doi', None)
        if doi:
            paper_url = f"https://doi.org/{doi}"
        else:
            # If DOI is not available, check for a link in the 'urls' field
            paper_url = next((url['value'] for url in paper['metadata'].get('urls', []) if url), None)

        # Retrieve the PDF link
        pdf_url = next((url['value'] for url in paper['metadata'].get('urls', []) if url.get('description') == 'Fulltext'), None)

        # Add the paper information to the HTML list with numbering
        html_content += f"""
        <li>
            <strong>{number}</strong>. {title}<br>
            {authors}<br>
        """

        # Only display journal, volume, year, and artid if available
        if journal_info:
            html_content += f"{journal_info}"
            if volume:
                html_content += f", {volume}"
            if year:
                html_content += f" ({year})"
            if artid:
                html_content += f", {artid}"
            html_content += "<br>"

        # Add arXiv number as a hyperlink if available
        if arxiv_number:
            html_content += f"<a href='https://arxiv.org/abs/{arxiv_number}' target='_blank'>{arxiv_number}</a><br>"

        # Add DOI if available
        if doi:
            html_content += f"<strong>DOI:</strong> <a href='https://doi.org/{doi}' target='_blank'>{doi}</a><br>"

        # Add a link to the paper URL if available without bold
        if paper_url:
            html_content += f"Link: <a href='{paper_url}' target='_blank'>View Paper</a><br>"

        # Add a link to the PDF if available without bold
        if pdf_url:
            html_content += f"PDF: <a href='{pdf_url}' target='_blank'>Download PDF</a><br>"

        # Close the list item
        html_content += "</li>"

    # Close the HTML tags
    html_content += """
        </ul>
    </body>
    </html>
    """

    # Get the directory of the current script
    script_dir = os.path.dirname(os.path.abspath(__file__))

    # Define the file path where you want to save the HTML file in the same folder
    file_path = os.path.join(script_dir, "xpand_acknowledged_papers.html")

    # Save the HTML content to a file in the same directory as the script
    with open(file_path, "w") as file:
        file.write(html_content)

    print(f"HTML file generated successfully at {file_path}!")

else:
    print("Failed to fetch data from Inspire HEP API")
